%leaky bucket

%written by HG 1/23/13

clear all
figure(2)
clf

%%initialize

g = 9.81; %gravity, m/s^2
R = 0.2; %radius of bucket
rhow = 1000; %density of water
Area = pi*R*R; %surface area of bucket, cylinder

r = 0.01; %radius of hole in base of bucket
H0 = 0.3; %initial height of water in bucket
Qin0 = 0.001; %m3/s

%time array
dt = 1; %in seconds
tmax = 2000;
t = 0:dt:tmax;
imax = length(t);

%filling of arrays and setting up initial conditions
H = zeros(size(t));
H(1) = H0; %filling in 1st array element in H
V = H(1)*Area; %initial volume

%choose your case for input histories
tog = 0; %if 1 steady inputs, if 0 oscillating
if(tog ==1)
Qin = Qin0 * ones(size(t)); %sets up constant input rate
elseif(tog==0)
% or for more complexity in inputs
P = 100; %period of oscillation
Qin_amp = (Qin0/2);
Qin = Qin0 + (Qin_amp * sin(2*pi*t/P)); %sinusoidal oscillation on top of background
end
Qout = zeros(size(t));
Qout(1) = 0;

%% run

for i=2:imax
    u = sqrt(2*H(i-1)*g);
    Qout(i) = u*pi*r*r;
    
    dVdt = (Qin(i) - Qout(i));
    V = V + (dVdt*dt);
    V = max(0,V); %disallows negative volume in the bucket
    
    H(i) = V/Area;
end

%% finalize

figure(1)
subplot(2,1,1)
plot(t,Qin*1000, 'r')
hold on
plot(t,Qout*1000, 'k')

set(gca,'fontsize',14,'fontname','arial')
%xlabel('time (s)','fontname','arial','fontsize',18)
ylabel('Qin (L/s)','fontname','arial','fontsize',18)

subplot(2,1,2)
plot(t,H,'linewidth',2)
set(gca,'fontsize',14,'fontname','arial')
xlabel('Time (s)','fontname','arial','fontsize',18)
ylabel('Height of water (m)','fontname','arial','fontsize',18)
axis([0 tmax 0 1.1*max(H)])






